########################################################################
# Config file parser/reader/validation routines.
########################################################################
# Basic rules:
# 1 - remove all whitespace
# 2 - '#' is the comment character. Ignore following text.
# 3 - properties take the value of this=that exactly
# 4 - Must account for all props in file - none can be missing
#     (corrupt file)
# 5 - Special characters not allowed (i.e.  *, ", ')
########################################################################

########################################################################
# Print any configuration read errors
########################################################################
print_conf_read_error()
{

echo "      (F) Config file parsing error.  Expected form 'property=value',"
echo "          but found value ($1) on line $line_count"
echo "          Only two forms accepted:"
echo "            1).  # = Comment"
echo "            2).  property takes the form 'property=value'"
echo ""
echo "            Corrupt config file - Exiting!"
echo ""

return 0;
}

########################################################################
# Validate all configuration options
########################################################################
validate_config_options()
{

# check for the existence of every required configuration parameter

if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_TOPDIR not found in config file"
  exit 5
elif [ -z "$TMPDIR" ]; then
  echo "      (F) ITMIC0005E Error.  Property TMPDIR not found in config file"
  exit 5
elif [ -z "$DB2_INST_DIR" ]; then
  echo "      (F) ITMIC0005E Error.  Property DB2_INST_DIR not found in config file"
  exit 5

elif [ -z "$DB2USER" ]; then
  echo "      (F) ITMIC0005E Error.  Property DB2USER not found in config file"
  exit 5
elif [ -z "$DB2PASS" ]; then
  echo "      (F) ITMIC0005E Error.  Property DB2PASS not found in config file"
  exit 5

elif [ -z "$TWH_CTRL_DB" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_CTRL_DB not found in config file"
  exit 5
elif [ -z "$TWH_CTRL_DB_USER" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_CTRL_DB_USER not found in config file"
  exit 5
elif [ -z "$TWH_CTRL_DB_PASS" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_CTRL_DB_PASS not found in config file"
  exit 5

elif [ -z "$TWH_CDW_DB" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_CDW_DB not found in config file"
  exit 5
elif [ -z "$TWH_CDW_DB_USER" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_CDW_DB_USER not found in config file"
  exit 5
elif [ -z "$TWH_CDW_DB_PASS" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_CDW_DB_PASS not found in config file"
  exit 5

elif [ -z "$TWH_DM_DB" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_DM_DB not found in config file"
  exit 5
elif [ -z "$TWH_DM_DB_USER" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_DM_DB_USER not found in config file"
  exit 5
elif [ -z "$TWH_DM_DB_PASS" ]; then
  echo "      (F) ITMIC0005E Error.  Property TWH_DM_DB_PASS not found in config file"
  exit 5
elif [ -z "$ITM_DB_TYPE" ]; then
  echo "      (F) ITMIC0005E Error.  Property ITM_DB_TYPE not found in config file"
  exit 5
elif [ -z "$ITM_DB_ALIAS" ]; then
  echo "      (F) ITMIC0005E Error.  Property ITM_DB_ALIAS not found in config file"
  exit 5
elif [ -z "$ITM_DB_USER" ]; then
  echo "      (F) ITMIC0005E Error.  Property ITM_DB_USER not found in config file"
  exit 5
elif [ -z "$ITM_DB_PASS" ]; then
  echo "      (F) ITMIC0005E Error.  Property ITM_DB_PASS not found in config file"
  exit 5
fi

### Basic tests on the config options

# check tmp dir
test_tmpdir;

# add here any other usefull test to validate configuration options
# ....

echo "      (I) Validated all configuration options"
return 0;

}

###############################################################################
# Read the config file and validate the supplied properties
###############################################################################
read_config_file()
{

config_file="$1"

echo "==> Reading Config File ($config_file)"

# Preset vars
line_count=0

# Open the config file
exec < "$config_file"

# Parse the config file
while :
do
  # Read the config file line by line
  read cur_line

  # Did we hit the end of the file?
  if [ ! $? -eq 0 ]; then break; fi

  line_count=`expr $line_count + 1`

  # clean whitespace and look for comment char
  cleaned_line=`echo "$cur_line" | sed "s/	//g" | sed "s/ //g"`
  echo "$cleaned_line" | grep -i "^#" > /dev/null
  if [ $? -eq 0  -o ! "$cleaned_line" ]; then
    continue
  fi

  # Now parse for properties and validate them
  echo "$cleaned_line" | grep "=" > /dev/null
  if [ ! $? -eq 0 ]; then
    print_conf_read_error $cleaned_line ;
    exit 5
  fi

  # Find the property tag and value (upcase the tag)
  property_line=`echo "$cleaned_line" | sed "s/#.*//" `
  prop_tag=`echo "$property_line" | sed "s/=.*//" | tr '[a-z]' '[A-Z]' `
  prop_val=`echo "$property_line" | sed "s/.*=//" `

  # Determine the property tag and set the property as a global Env variable
  case $prop_tag in
    #
    TWH_TOPDIR)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_TOPDIR="$prop_val";
        export TWH_TOPDIR
        ;;
    #
    TMPDIR)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TMPDIR="$prop_val";
        export TMPDIR
        ;;
    #
    DB2_INST_DIR)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        DB2_INST_DIR="$prop_val";
        export DB2_INST_DIR
        ;;
    #
    DB2USER)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        DB2USER="$prop_val";
        export DB2USER
        ;;
    #
    DB2PASS)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        DB2PASS="$prop_val";
        export DB2PASS
        ;;
    #
    DB2PASS)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        DB2PASS="$prop_val";
        export DB2PASS
        ;;
    #
    TWH_CTRL_DB)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CTRL_DB="$prop_val";
        export TWH_CTRL_DB
        ;;
    #
    TWH_CTRL_DB_USER)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CTRL_DB_USER="$prop_val";
        export TWH_CTRL_DB_USER
        ;;
    #
    TWH_CTRL_DB_PASS)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CTRL_DB_PASS="$prop_val";
        export TWH_CTRL_DB_PASS
        ;;
    #
    TWH_CDW_DB)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CDW_DB="$prop_val";
        export TWH_CDW_DB
        ;;
    #
    TWH_CDW_DB_USER)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CDW_DB_USER="$prop_val";
        export TWH_CDW_DB_USER
        ;;
    #
    TWH_CDW_DB_PASS)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_CDW_DB_PASS="$prop_val";
        export TWH_CDW_DB_PASS
        ;;
    #
    TWH_DM_DB)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_DM_DB="$prop_val";
        export TWH_DM_DB
        ;;
    #
    TWH_DM_DB_USER)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_DM_DB_USER="$prop_val";
        export TWH_DM_DB_USER
        ;;
    #
    TWH_DM_DB_PASS)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        TWH_DM_DB_PASS="$prop_val";
        export TWH_DM_DB_PASS
        ;;
    #
    ITM_DB_TYPE)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        ITM_DB_TYPE="$prop_val";
        export ITM_DB_TYPE
        ;;
    #
    ITM_DB_ALIAS)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        ITM_DB_ALIAS="$prop_val";
        export ITM_DB_ALIAS
        ;;
    #
    ITM_DB_USER)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        ITM_DB_USER="$prop_val";
        export ITM_DB_USER
        ;;
    #
    ITM_DB_PASS)
	if [ $DEBUG ]; then echo "$prop_tag found"; fi
        ITM_DB_PASS="$prop_val";
        export ITM_DB_PASS
        ;;
    # Default - is an error: fouded more name,value pairs then expected
    *)
        echo "      (F) ITMIC0007E Illegal option found."
        echo "          Illegal value is ($prop_tag)"
        exit 7
        ;;
  esac
done

# Detect any missing properties
validate_config_options;

echo "      (I) Completed reading Config File"
return 0;
}

