#!/bin/sh
###############################################################################
#
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#  File Information: %W%
#  Revision: %I%
#  Date: %G% %U%
#
###############################################################################

###############################################################################
# Set global Env variables
# To call: set_program_vars;
###############################################################################
set_program_vars()
{

# Extend the system path for DB2 tools
PATH="$PATH:$DB2_INST_DIR/BIN:$DB2_INST_DIR/FUNCTION:$DB2_INST_DIR/HELP"
export PATH

# DB2 Configurable Vars
DB2CMD="db2cmd /w /c /i"
DB2CARGS="/w /c /i"         # The DB2 cmd line
DB2PROG="db2"               # DB2 interface command
DB2EXEC="$DB2CMD $DB2PROG"  # Execute db2 command

# TEDW Configurable Vars
EXECSQL=$TWH_TOPDIR/tools/bin/execsql.exe

# Program Configurable Vars
TRUE=1
FALSE=0
REPORT_FILENAME="report.txt"

return 0;
}

###############################################################################
# Heuristically test the supplied temporary directory
# To call: test_tmpdir;
###############################################################################
test_tmpdir()
{

# does the specified temporary directory exist
if [ ! -d "$TMPDIR" ]; then
  #no, create it
  mkdir "$TMPDIR"
fi

# check if the temporary directory is accessible 
# attempting to create a file in it
_testfile=test_tmp.txt
blah=`touch "$TMPDIR/$_testfile" 2>&1 `
if [ $? -ne 0 ]; then
  echo "      (F) ITMIC0012E Temp directory ($TMPDIR) is not accessible."
  echo "          Needed for the successful execution of the analysis tool."
  exit 10
else
  blah=`rm "$TMPDIR/$_testfile" 2>&1`
fi

echo "      (I) Temp Directory is ($TMPDIR) and is accessible";

return 0;
}

###############################################################################
# Prepare the Analysis report into the ./out directory
# To call:	prepare_report;
###############################################################################
prepare_report()
{

# the analysis results are stored into the ./out directory
_report_file="./out/$REPORT_FILENAME";

# check if the ./out directory is accessible
blah=`touch "$_report_file" 2>&1 `
if [ $? -ne 0 ]; then
  echo "      (F) ITMIC0010E Out directory (./out) is not accessible."
  echo "          Needed for the successful execution of the analysis tool."
  exit 10
else
  blah=`rm "$_report_file" 2>&1`
fi

echo "==> Preparing the Analysis Report";

# set the date of the report
_date=`date`;

echo "
  ================================================================
  === IBM Tivoli Monitoring - Tivoli Enterprise Data Warehouse ===
  ================================================================
  ======================== Analysis Report =======================
  ================================================================
  Report created on: $_date
  ================================================================
" > $_report_file;

echo "      (I) Report prepared in ($_report_file) "

return 0;
}


###############################################################################
# Writes a string into the analysis report.
# To call:	put_info $1;
#	$1 = String message
###############################################################################
put_info()
{

message="$1";

_report_file="./out/$REPORT_FILENAME";

# check if the report file really exists
if [ ! -e "$_report_file" ]; then
  echo "      (F) ITMIC0011E Report file doesn't exist: cannot write a message to it."
  exit 11
fi

echo "
  ================================================================
  $message
  ================================================================
" >> $_report_file;

return 0;
}

###############################################################################
# Return codes and messages displayed by the program
# To call:	display_return_code_messages;
###############################################################################
display_return_code_messages()
{

echo ""
echo "    ========================================================"
echo "    ================= Return Code Messages ================="
echo "    ========================================================"
echo ""
echo "    05 = "Property not found in config file"
echo "    07 = "Illegal option found."
echo ""
echo "    10 = Out directory (./out) is not accessible."
echo "    11 = Report file doesn't exist: cannot write a message to it."
echo "    12 = Temp directory is not accessible."
echo ""
echo "    20 = Unknown Database Type: cannot create an executable script"
echo "    21 = Error trying to read the execution script"
echo "    22 = Errror executing the script "
echo ""

return 0;
}

###############################################################################
# Provides a snapshot of the installed TEDW components, fixpacks, e-fix
# To call:	tedw_inventory;
###############################################################################
tedw_inventory()
{

#
# TWH Core components
#
echo ""
echo "    TWH Core Components and FixPacks Installed:";
echo "";
echo "    Date                    App         Version";
echo "    --------------------------------------------------------";
ls -ltacrR --full-time $TWH_TOPDIR | grep "twh_core_v.*\.marker" | sed "s/\.marker//g" | sed "s/\.//" | (
while read a b c d e f g h i j k
do
  core="TEDW";
  version=`echo "$k" | sed "s/twh_core_v*//" `
  inst_date=`echo "$g" "$h" "$i" "$j"`  
  echo "    $inst_date    $core        $version";
done 
)
#
# TWH App components
#
echo ""
echo "    TWH Warehouse Enablement Packs and FixPacks Installed:";
echo "";
echo "    Date                    Wep         Version";
echo "    --------------------------------------------------------";
ls -ltacrR --full-time $TWH_TOPDIR | grep "twh_..._v.*\.marker" | sed "s/\.marker//g" | sed "s/\.//" | (
while read a b c d e f g h i j k 
do
  wep=`echo "$k" | sed "s/twh_*//" | sed "s/_v.*//" | tr '[a-z]' '[A-Z]' `
  version=`echo "$k" | sed "s/twh_..._v*//" `
  inst_date=`echo "$g" "$h" "$i" "$j"`
  echo "    $inst_date    $wep         $version";
done 
)
echo ""
echo "    ========================================================";
echo ""

return 0;
}