--
-- NOTE: this script is executed by the execsql processor, 
-- using the ODBC alias specified in the configuration file.
--
-- You get exception records logged into the AMX.STAGE_ATTRTYP_TRANSL_EX if:
--   -  Some attributes of a component type are not declared in the metadata 
--      table AMX.AttrTyp_Transl;
--   -  A component having a unique key (not a composite key)has this key 
--      declared as an attribute and it should not;
--   -  The ITM attribute name that is part of a composite key is not the 
--      same in the metadata tables AMX.CompTyp_Transl and AMX.AttrTyp_Transl;
--
VALUES('Attribute Type Translation Exceptions (AMX.STAGE_ATTRTYP_TRANSL_EX)');
SELECT
  COMPTYP_CD             AS COMPTYP_CD,
  MSRC_CD                AS MSRC_CD,
  SUBSTR(ERROR_MSG,1,70) AS ERROR_MSG,
  TIMESTAMP              AS TIMESTAMP
FROM
  AMX.STAGE_ATTRTYP_TRANSL_EX
;
--
-- You get exception records logged into the AMX.STAGE_COMPTYP_TRANSL_EX if:
--   - There is a component type in the TWG.RelnRul that do not exist in the 
--     AMX.CompTyp_Transl table;
--
VALUES('Component Type Translation Exceptions (AMX.STAGE_COMPTYP_TRANSL_EX)');
SELECT 
  COMPTYP_CD             AS COMPTYP_CD,
  MSRC_CD                AS MSRC_CD,
  SUBSTR(ERROR_MSG,1,70) AS ERROR_MSG,
  TIMESTAMP              AS TIMESTAMP
FROM
  AMX.STAGE_COMPTYP_TRANSL_EX
;
--
-- You get exception records logged into the AMX.STAGE_INST_COMP_PAC_EX if:
--   - The ITM instance key in the AMX.Stage_Key_Parsed contains at least
--     one key that is not pre-defined in the metadata for that application;
--
VALUES('Invalid keys found during parsing (AMX.STAGE_INST_COMP_PAC_EX)');
SELECT 
  PAC                    AS PAC,
  COMPTYP_CD             AS COMPTYP_CD,          
  SUBSTR(ERROR_MSG,1,70) AS ERROR_MSG,
  SUBSTR(PROPERTY,1,70)  AS PROPERTY,
  TIMESTAMP              AS TIMESTAMP
FROM
  AMX.STAGE_INST_COMP_PAC_EX
;
--
-- You get exception records logged into the AMX.STAGE_CATEGORIES_EX if:
--   - Properties that are inside the CATEGORIES table are not declared 
--     as attributes for that component type in the metadata table 
--     AMX.AttrTyp_Transl;
--
VALUES('Missing Metadata for the specified Category (AMX.STAGE_CATEGORIES_EX)');
SELECT
  PAC                    AS PAC,
  COMPTYP_CD             AS COMPTYP_CD,          
  SUBSTR(ERROR_MSG,1,70) AS ERROR_MSG,
  SUBSTR(NAME,1,70)      AS NAME,
  TIMESTAMP              AS TIMESTAMP
FROM
  AMX.STAGE_CATEGORIES_EX
;
--
-- You get exception records logged into the AMX.STAGE_METRICS_EX if:
--   - Metric names in the ITM METRICS table are not defined in the 
--     metadata table TWG.MsmtTyp;
--
VALUES('Missing Metadata for the specified Metric (AMX.STAGE_METRICS_EX)');
SELECT
  PAC                    AS PAC,
  SUBSTR(ERROR_MSG,1,70) AS ERROR_MSG,
  SUBSTR(NAME,1,70)      AS NAME,
  TIMESTAMP              AS TIMESTAMP
FROM
  AMX.STAGE_METRICS_EX
;
--
-- You get exception records logged into the AMX.STAGE_RELNRUL_TRANSL_EX if:
--   - In the AMX.RelnRul_Transl table there is a source component type that 
--     does not correspond to a component type in the metadata table 
--     TWG.CompTyp table;
--
VALUES('Missing Metadata for the specified Source Component (AMX.STAGE_RELNRUL_TRANSL_EX)');
SELECT
  COMPTYP_SOURCE_CD      AS COMPTYP_SOURCE_CD,
  COMPTYP_TARGET_CD      AS COMPTYP_TARGET_CD,    
  RELNTYP_CD             AS RELNTYP_CD,
  SUBSTR(ERROR_MSG,1,70) AS ERROR_MSG,
  TIMESTAMP              AS TIMESTAMP
FROM
  AMX.STAGE_RELNRUL_TRANSL_EX
;
--
-- You get exception records logged into the AMX.STAGE_RESOURCE_TRANSL_EX if:
--   - In the AMX.stage1_resources table, there is no corresponding component 
--     type code in the table TWG.CompTyp;
--   - The AMX.RelnRul_Transl table contains a relation type different from 
--     PROXY, PCHILD, SAME;
--   - A component source type without a host for parent has a PROXY relationship;
--
VALUES('Missing Metadata for the specified Resource (AMX.STAGE_RESOURCE_TRANSL_EX)');
SELECT
  SUBSTR(RESOURCE,1,30)  AS RESOURCE,    
  COMPTYP_CD             AS COMPTYP_CD,
  SUBSTR(ERROR_MSG,1,70) AS ERROR_MSG,
  TIMESTAMP              AS TIMESTAMP
FROM
  AMX.STAGE_RESOURCE_TRANSL_EX
;

--
-- You get exception records logged into the AMX.STAGE_RMPROFILES_EX if:
--   - In the source RMPROFILES table there is a category that does not 
--     correspond to a category in the metadata table AMX.Category_Transl;
--
VALUES('Missing Metadata for the specified Resource Model Category (AMX.STAGE_RMPROFILES_EX)');
SELECT
  SUBSTR(CATEGORY,1,20)       AS CATEGORY,
  SUBSTR(PROFILE,1,20)        AS PROFILE, 
  SUBSTR(RESOURCE_MODEL,1,20) AS RESOURCE_MODEL,
  SUBSTR(ERROR_MSG,1,40)      AS ERROR_MSG,
  TIMESTAMP                   AS TIMESTAMP
FROM
  AMX.STAGE_RMPROFILES_EX
;
